NotificationsPackage class abstract

Inheritance
  • Object
  • Package
  • NotificationsPackage
Implementers

Constructors

NotificationsPackage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
packageName → String
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateConditionMemberHasUnreadNotifications → Map<String, bool?>
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
subscription → Map<String, StreamSubscription<List<NotificationModel?>>>
final

Methods

createPackageAppBloc(String appId, AccessBloc accessBloc) → BlocProvider<StateStreamableSource<Object?>>?
inherited
getAndSubscribe(AccessBloc accessBloc, AppModel app, MemberModel? member, bool isOwner, bool? isBlocked, PrivilegeLevel? privilegeLevel) → Future<List<PackageConditionDetails>>?
override
getMemberCollectionInfo() → List<MemberCollectionInfo>
override
init() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerDependencies(Eliud eliud) → void
override
retrieveAllPackageConditions() → List<String>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

conditionMemberHasUnreadNotifications → String
final

Static Methods

getOpenNotificationsQuery(String? appId, String? assigneeId) → EliudQuery
instance() → NotificationsPackage